@@ -6,39 +6,6 @@ from .helper import fetch_celex_resource
 
 
 
-#class SegmentType(models.Model):
-#    Label = models.CharField(max_length=10)
-#    Syllabic = models.NullBooleanField()
-#    Obstruent = models.NullBooleanField()
-#    Nasal = models.NullBooleanField()
-#    Vowel = models.NullBooleanField()
-#
-#    def guessProperties(self):
-#        NasalInd = ['n','m']
-#        VowelInd = set(['i','u','o','e','a'])
-#        ApproxInd = ['r','l','y']
-#        for s in self.Label.lower():
-#            if s in VowelInd:
-#                self.Vowel = True
-#                break
-#        else:
-#            self.Vowel = False
-#        self.save()
-#
-#    def isSyllabic(self):
-#        return self.Syllabic
-#
-#    def isNasal(self):
-#        return self.Nasal
-#
-#    def isObs(self):
-#        return self.Obstruent
-#
-#    def isVowel(self):
-#        return self.Vowel
-#
-#    def __unicode__(self):
-#        return u'%s' % (self.Label,)
 
 class SyntacticCategory(models.Model):
     label = models.CharField(max_length=50)
@@ -49,13 +16,6 @@ class SyntacticCategory(models.Model):
         return self.label
 
 
-#class CatRelationship(models.Model):
-#    Word = models.ForeignKey('Word')
-#    Category = models.ForeignKey(SyntacticCategory)
-#    Count = models.BigIntegerField(blank=True,null=True)
-
-#    class Meta:
-#        ordering = ['-Count']
 
 
 class Transcription(models.Model):
@@ -124,8 +84,11 @@ class Lemma(models.Model):
     def get_transcriptions(self):
         return ".".join(str(t) for wf in WordForm.objects.filter(lemma=self) for t in wf.transcriptions.all())
 
+    def get_spelling_set(self):
+        return {str(s) for wf in WordForm.objects.filter(lemma=self) for s in wf.orthographies.all()}
+
     def get_spellings(self):
-        return ", ".join(str(s) for wf in WordForm.objects.filter(lemma=self) for s in wf.orthographies.all())
+        return ", ".join(self.get_spelling_set())
 
     #def getPrimaryCategory(self):
     #    if self.PrimaryCategory is not None:
