@@ -25,7 +25,7 @@ def categorize_words(words):
         else:
             t.append((x,(['NA']+[str(y.category).lower() for y in qs if x in y.get_spelling_set()])[-1]))
             if t[-1][1] == 'adv':
-                t[-1][1] = 'r'
+                t[-1] = (t[-1][0],'r')
     return ['#'.join(x) for x in t if x[1]]
 
 
